@@ -41,6 +41,8 @@ _SUPPORTED_USERS['cloud-admin']='cloud-admin 42401 42401 /home/cloud-admin'
 _SUPPORTED_USERS['collectd']='collectd 42409 42409 /var/lib/collectd kolla'
 _SUPPORTED_USERS['designate']='designate 42411 42411 /var/lib/designate kolla'
 _SUPPORTED_USERS['etcd']='etcd 42413 42413 /var/lib/etcd kolla'
+_SUPPORTED_USERS['frrvty']='frrvty 42483 42483'
+_SUPPORTED_USERS['frr']='frr 42484 42484 /var/run/frr kolla,frrvty'
 _SUPPORTED_USERS['glance']='glance 42415 42415 /var/lib/glance kolla'
 _SUPPORTED_USERS['gnocchi']='gnocchi 42416 42416 /var/lib/gnocchi kolla'
 _SUPPORTED_USERS['haproxy']='haproxy 42454 42454 /var/lib/haproxy kolla'
@@ -68,8 +70,6 @@ _SUPPORTED_USERS['qemu']='qemu 107 107'
 _SUPPORTED_USERS['rabbitmq']='rabbitmq 42439 42439 /var/lib/rabbitmq kolla'
 _SUPPORTED_USERS['redis']='redis 42460 42460 /run/redis kolla'
 _SUPPORTED_USERS['swift']='swift 42445 42445 /var/lib/swift kolla'
-_SUPPORTED_USERS['tempest']='tempest 42480 42480 /var/lib/tempest kolla'
-_SUPPORTED_USERS['tss']='tss 42485 42485 /var/lib/tpm kolla'
 _SUPPORTED_USERS['zaqar']='zaqar 42452 42452 /var/lib/zaqar kolla'
 
 for _USER_TO_CREATE in $_USERS_TO_CREATE; do
