@@ -21,10 +21,8 @@ import yaml
 import six
 from six.moves import cStringIO as StringIO
 
-from tripleo_common import constants
 from tripleo_common.exception import NotFound
 from tripleo_common.exception import RoleMetadataError
-from tripleo_common.utils import stack_parameters as stack_param_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -188,60 +186,3 @@ def validate_role_yaml(role_data=None, role_path=None):
                         role['name'], k, schema[k]['type'])
                     raise RoleMetadataError(msg)
     return role
-
-
-def get_roles_from_plan(swift, heat=None,
-                        container=constants.DEFAULT_CONTAINER_NAME,
-                        role_file_name=constants.OVERCLOUD_J2_ROLES_NAME,
-                        detail=False, valid=False):
-
-    """Returns a deployment plan's roles list
-
-    Parses roles_data.yaml and returns the names of all available/valid roles.
-
-    :param swift: legacy object client
-    :param heat: legacy orchestration client
-    :param container: name of the Swift container / plan name
-    :param roles_file_name: name of the foles file
-    :param detail: if false(default), displays role names only.  if true,
-                   returns all roles data
-    :param valid: check if the role has count > 0 in heat environment
-    :return: list of roles in the container's deployment plan
-    """
-
-    try:
-        roles_data = yaml.safe_load(swift.get_object(
-            container, role_file_name)[1])
-    except Exception as err:
-        err_msg = ("Error retrieving roles data from deployment plan: %s"
-                   % err)
-        LOG.exception(err_msg)
-        raise RuntimeError(err_msg)
-
-    if detail:
-        return roles_data
-
-    role_names = [role['name'] for role in roles_data]
-
-    if not valid:
-        return role_names
-
-    assert heat is not None
-
-    try:
-        heat_resource_tree = stack_param_utils.get_flattened_parameters(
-            swift, heat, container)['heat_resource_tree']
-    except Exception as err:
-        err_msg = ("Error retrieving getting heat resource tree: %s"
-                   % err)
-        LOG.exception(err_msg)
-        raise RuntimeError(err_msg)
-
-    valid_roles = []
-    for name in role_names:
-        role_count = heat_resource_tree['parameters'].get(
-            name + 'Count', {}).get('default', 0)
-        if role_count > 0:
-            valid_roles.append(name)
-
-    return valid_roles
